function [x,lambda,status] = clp(Q,c,A,b,Aeq,beq,lb,ub,vartype,options)
// CLP Interface to LP/QP solver CLP
//
// [x,z,status] = clp(Q,c,A,b,Aeq,beq,lb,ub,vartype,options)
//
// min c'*x
// s.t   A*x <  b, Aeq*x == beq, lb < x < ub
//
// Options structure (see CLP user manual for details)
//    options.solver           [1 (primal)| 2 (dual), (default 1)].
//    options.maxnumiterations [int>=0 (default 99999999)]
//    options.maxnumseconds    [int>=0 (default 3600)]
//    options.primaltolerance  [double>=0 (default 1e-7)]
//    options.dualtolerance    [double>=0 (default 1e-7)]
//    options.primalpivot      [1 (steepest) | 2 (Dantzig) (default 1)]
//    options.dualpivot        [1 (steepest) | 2 (Dantzig) (default 1)]
//    options.verbose          [0|1|... (default 0)]
//
// output
//  x      : primal
//  z      : dual
//  status : 0 - optimal, 1 - infeasible, 2- unbounded

// Author Johan Lfberg ETH Zrich.
// $Id: clp.m,v 1.1 2006/02/01 14:14:31 joloef Exp $

[nargout,nargin] = argn();

//
// Check input
//

if ~isdef('options','local') then option  = []; end
if ~isdef('vartype','local') then vartype = []; end
if ~isdef('ub','local')      then ub  = []; end
if ~isdef('lb','local')      then lb  = []; end
if ~isdef('beq','local')     then beq = []; end
if ~isdef('Aeq','local')     then Aeq = []; end
if ~isdef('b','local')       then b = []; end
if ~isdef('A','local')       then A = []; end
if ~isdef('c','local')       then c = []; end
if ~isdef('Q','local')       then Q = []; end

if nargin < 1 then
  printf('warning: some parameters must be defined\n');
  printf('function [x,lambda,status] = clp(Q,c,A,b,Aeq,beq,lb,ub,vartype,options)\n');
  return;
end

if isempty(c) then
  c = ones(1,size(A,2));
end

//
// Merge constraints
//

A = [Aeq;A];
b = [beq;b];

// Bug in mexclp...
if isempty(b) then
    if isempty(Q) | (nnz(Q)==0) then
        x = zeros(length(c),1);
        lambda = [];
        status = 2;
        return
    end
    x = -Q\c;
    lambda = [];
    status = 0;
    return;
end

//
// CLP sparse format
//

c   = full(c(:))';
b   = full(b(:))';
neq = length(beq);
lb  = full(lb(:)');
ub  = full(ub(:)');

//
// Call Scilab Clp interface
//

[x,lambda,status] = sciclp(A,c,b,neq,lb,ub,vartype,Q,options);   

endfunction
